#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-ABi3CuZMdW78QTVBoJtGwZ
key:                  ghcide-2.3.0.0-ABi3CuZMdW78QTVBoJtGwZ
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  152a96176ba4eddf8da3f9407d5390c4
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-ABi3CuZMdW78QTVBoJtGwZ
depends:
    Diff-0.5-BjbdKLuZHF9G9mgcT2QyXB Glob-0.10.2-IutOkyaNcwRCJvH1GtzLC7
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR array-0.5.6.0
    async-2.2.6-IB55pRMOICm7lPJ05sVN9d base-4.18.2.1
    base16-bytestring-1.0.2.0-DSxrKsTmVLa6G5QgZxymlm binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Gzh99I2Ds5LB1yZuFXcZ2A
    co-log-core-0.3.2.6-GOaMig8GoMG77PnNMP0jCG containers-0.6.7
    cryptohash-sha1-0.11.101.0-5BEhjJUDbRY5n4GkZJCIw0
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-1LACIxNivdPb9khY8cdu6
    dependent-sum-0.7.2.0-JKOwbLfQQ3B5Cd2RuzcmqQ directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-7TD6SN1GIwvAqFTzckWqNs exceptions-0.10.7
    extra-1.7.16-1gq06OiTdkG7AFSCXWttYR filepath-1.4.300.1
    fingertree-0.1.6.3-FSPXoGBl4dR2SNeWItcpUR
    focus-1.0.3.2-8WvVuORN6DY8ig9GpJ0Prt ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-2K7mbAF3LEI1DrXbfZr4LL
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-I1ozfPpxuY6EbrTPFlz8Ey
    hashable-1.4.7.0-ISMWzeTPqg7GxJZ08wJoa
    hie-bios-0.12.0-B0aRF4nJwOWK0PGLfSx88C
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-CpGQiEnMvnzDTgQq628ZrL
    hls-graph-2.3.0.0-HpLGg0l7xYvEeFSog7qEQs
    hls-plugin-api-2.3.0.0-8ov4juJAzGVH8FUkWtxMdw
    implicit-hie-0.1.4.0-w7Eo4h7R4y1niwHOtfKUZ
    implicit-hie-cradle-0.5.0.1-73zVIVFhrsS2Oy14HTaeNF
    lens-5.3.4-6xqoTm4kiuC8ULAJ3RTBph
    list-t-1.0.5.7-BfBwcT7UQBy7LiiDdP5O3a
    lsp-2.2.0.0-G42MvkI8UUDFwGwofUskp3
    lsp-types-2.0.2.0-LmHG0NjoDNe4jC9nPopLX6 mtl-2.3.1
    opentelemetry-0.8.0-E8CiduTybKu2aaQbTT7Y7G
    optparse-applicative-0.18.1.0-ACOZXD1ji7S90GHMXot2xe
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-7RKzVGBzgxT19LUdxVNO6E
    prettyprinter-ansi-terminal-1.1.4-3YWnN8nP22KOcxelH2Y20
    random-1.2.1.3-IIwS2aSfjMyGbtdCPZwDHA
    regex-tdfa-1.3.2.5-8NW0m2HiVCwIy0zxjhdOWx
    row-types-1.0.1.2-ImFsHUkJrRkHT2QtgIv6bk
    safe-exceptions-0.1.7.4-55TadAijt349fxpbRixfL
    sorted-list-0.2.3.1-J8Ox2R7t0v8BNEDBiTBkEj
    sqlite-simple-0.4.19.0-BVg4bkGPqMT7jHfjWiiQBQ stm-2.5.1.0
    stm-containers-1.2.1.1-4oo58G3bSv85S1AnFSkrcQ
    syb-0.7.3-AsxB5kY1s6JBFiF2Kn9gZL text-2.0.2
    text-rope-0.3-60x43MeTgQM9Mcl7DeWkES time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-2ijZcbxfdeVCmMwCRtThrP
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1
    vector-0.13.2.0-B5QnucNm6YY8XIvh7YleVY

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

